@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 """ Read worksheets on-demand
 """
@@ -68,7 +68,7 @@ class ReadOnlyWorksheet(object):
         self._current_row = None
         self.worksheet_path = worksheet_path
         self.shared_strings = shared_strings
-        self.base_date = parent_workbook.excel_base_date
+        self.base_date = parent_workbook.epoch
         self.xml_source = xml_source
         dimensions = read_dimension(self.xml_source)
         if dimensions is not None:
@@ -180,13 +180,13 @@ class ReadOnlyWorksheet(object):
             col_counter = column + 1
 
         if max_col is not None:
-            for _ in range(col_counter, max_col+1):
+            for _ in range(max(min_col, col_counter), max_col+1):
                 yield EMPTY_CELL
 
 
     def _get_cell(self, row, column):
         """Cells are returned by a generator which can be empty"""
-        for row in self.get_squared_range(column, row, column, row):
+        for row in self._cells_by_row(column, row, column, row):
             if row:
                 return row[0]
         return EMPTY_CELL
@@ -197,6 +197,10 @@ class ReadOnlyWorksheet(object):
         return self.iter_rows()
 
 
+    def __iter__(self):
+        return self.iter_rows()
+
+
     def calculate_dimension(self, force=False):
         if not all([self.max_column, self.max_row]):
             if force:
